@@ -37,7 +37,7 @@ load <- function(project = getwd(), quiet = FALSE) {
   # if we're loading a project different from the one currently loaded,
   # then unload the current project and reload the requested one
   switch <-
-    !is.null(Sys.getenv("RENV_PROJECT")) &&
+    !is.na(Sys.getenv("RENV_PROJECT", unset = NA)) &&
     !identical(project, renv_project())
 
   if (switch)
@@ -55,14 +55,16 @@ load <- function(project = getwd(), quiet = FALSE) {
   }
 
   # load rest of renv components
+  renv_load_init(project)
   renv_load_path(project)
   renv_load_shims(project)
   renv_load_renviron(project)
+  renv_load_profile(project)
   renv_load_settings(project)
   renv_load_project(project)
   renv_load_sandbox(project)
   renv_load_libpaths(project)
-  renv_load_profile(project)
+  renv_load_rprofile(project)
   renv_load_cache(project)
 
   lockfile <- renv_lockfile_load(project)
@@ -135,6 +137,24 @@ renv_load_r_repos <- function(repos) {
 
 }
 
+renv_load_init <- function(project) {
+
+  # warn if the project path cannot be translated into the native encoding,
+  # as (especially on Windows) this will likely prevent renv from working
+  actual <- enc2utf8(project)
+  expected <- catch(enc2utf8(enc2native(actual)))
+  if (identical(actual, expected))
+    return(TRUE)
+
+  msg <- paste(
+    "the project path cannot be represented in the native encoding;",
+    "renv may not function as expected"
+  )
+
+  warning(msg)
+
+}
+
 renv_load_path <- function(project) {
 
   # only required when running in RStudio
@@ -182,9 +202,16 @@ renv_load_renviron <- function(project) {
 
 }
 
+renv_load_profile <- function(project) {
+
+  renv_bootstrap_profile_load(project = project)
+
+}
+
 renv_load_settings <- function(project) {
 
-  settings <- file.path(project, "renv/settings.R")
+  components <- c(project, renv_profile_prefix(), "renv/settings.R")
+  settings <- paste(components, collapse = "/")
   if (!file.exists(settings))
     return(FALSE)
 
@@ -223,7 +250,7 @@ renv_load_project <- function(project) {
 
 }
 
-renv_load_profile <- function(project = NULL) {
+renv_load_rprofile <- function(project = NULL) {
 
   project <- renv_project_resolve(project)
 
@@ -235,13 +262,13 @@ renv_load_profile <- function(project = NULL) {
 
   profile <- Sys.getenv("R_PROFILE_USER", unset = "~/.Rprofile")
   if (file.exists(profile))
-    renv_load_profile_impl(profile)
+    renv_load_rprofile_impl(profile)
 
   TRUE
 
 }
 
-renv_load_profile_impl <- function(profile) {
+renv_load_rprofile_impl <- function(profile) {
 
   status <- catch(eval(parse(profile), envir = globalenv()))
   if (!inherits(status, "error"))
@@ -271,7 +298,8 @@ renv_load_sandbox <- function(project) {
 renv_load_python <- function(project, fields) {
 
   # set a default reticulate Python environment path
-  envpath <- file.path(project, "renv/python/r-reticulate")
+  components <- c(project, renv_profile_prefix(), "renv/python/r-reticulate")
+  envpath <- paste(components, collapse = "/")
   Sys.setenv(RETICULATE_MINICONDA_PYTHON_ENVPATH = envpath)
 
   # nothing more to do if no lockfile fields set
@@ -407,7 +435,16 @@ renv_load_report_project <- function(project) {
     renv_session_quiet()
   )
 
-  if (!quiet) {
+  if (quiet)
+    return()
+
+  profile <- renv_profile_get()
+  version <- renv_package_version("renv")
+
+  if (length(profile)) {
+    fmt <- "* (%s) Project '%s' loaded. [renv %s]"
+    vwritef(fmt, profile, aliased_path(project), version)
+  } else {
     fmt <- "* Project '%s' loaded. [renv %s]"
     vwritef(fmt, aliased_path(project), renv_package_version("renv"))
   }
@@ -430,7 +467,8 @@ renv_load_report_updates <- function(project) {
 # nocov start
 renv_load_report_updates_impl <- function(project) {
 
-  if (!file.exists(file.path(project, "renv.lock")))
+  lockpath <- renv_lockfile_path(project = project)
+  if (!file.exists(lockpath))
     return(FALSE)
 
   status <- update(project = project, check = TRUE)
