@@ -52,3 +52,8 @@ skip_if_no_miniconda <- function(python) {
   TRUE
 
 }
+
+skip_sometimes <- function(freq = 0.80) {
+  threshold <- sample.int(100L, size = 1L)
+  testthat::skip_if(freq * 100 >= threshold)
+}
