@@ -36,8 +36,8 @@
 #'
 #' \item{`"explicit"`}{
 #' Only capture packages which are explicitly listed in the project
-#' `DESCRIPTION` file. This workflow is recommended for users who wish to more
-#' explicitly manage a project's \R package dependencies.
+#' `DESCRIPTION` file. This workflow is recommended for users who wish to
+#' manage their project's \R package dependencies directly.
 #' }
 #'
 #' \item{`"custom"`}{
@@ -53,7 +53,11 @@
 #'
 #' By default, `"implicit"`-style snapshots are used. The snapshot type can be
 #' configured on a project-specific basis using the `renv` project [settings]
-#' mechanism.
+#' mechanism. For example, to use `"explicit"` snapshots in a project:
+#'
+#' ```
+#' renv::settings$snapshot.type("explicit")
+#' ````
 #'
 #' When the `packages` argument is set, `type` is ignored, and instead only the
 #' requested set of packages, and their recursive dependencies, will be written
@@ -70,8 +74,7 @@
 #'   directly instead.
 #'
 #' @param type The type of snapshot to perform. See **Snapshot Type** for
-#'   more details. When `NULL` (the default), an "implicit"-style snapshot
-#'   is performed.
+#'   more details.
 #'
 #' @param packages A vector of packages to be included in the lockfile. When
 #'   `NULL` (the default), all packages relevant for the type of snapshot being
@@ -82,6 +85,9 @@
 #' @param force Boolean; force generation of a lockfile even when pre-flight
 #'   validation checks have failed?
 #'
+#' @param reprex Boolean; generate output appropriate for embedding the lockfile
+#'   as part of a [reprex](https://www.tidyverse.org/help/#reprex)?
+#'
 #' @return The generated lockfile, as an \R object (invisibly). Note that
 #'   this function is normally called for its side effects.
 #'
@@ -93,11 +99,12 @@
 snapshot <- function(project  = NULL,
                      ...,
                      library  = NULL,
-                     lockfile = file.path(project, "renv.lock"),
+                     lockfile = paths$lockfile(project = project),
                      type     = settings$snapshot.type(project = project),
                      packages = NULL,
                      prompt   = interactive(),
-                     force    = FALSE)
+                     force    = FALSE,
+                     reprex   = FALSE)
 {
   renv_consent_check()
   renv_scope_error_handler()
@@ -127,6 +134,10 @@ snapshot <- function(project  = NULL,
   if (is.null(lockfile))
     return(new)
 
+  # if running as part of 'reprex', then render output inline
+  if (reprex)
+    return(renv_snapshot_reprex(new))
+
   # TODO: do we still want to snapshot if the user cancels
   # the R-level snapshot?
   on.exit(renv_python_snapshot(project), add = TRUE)
@@ -189,7 +200,7 @@ snapshot <- function(project  = NULL,
   renv_infrastructure_write_rbuildignore(project)
 
   # ensure the activate script is up-to-date
-  renv_infrastructure_write_activate(project)
+  renv_infrastructure_write_activate(project, create = FALSE)
 
   invisible(new)
 }
@@ -907,3 +918,26 @@ renv_snapshot_fixup_renv <- function(records) {
   # nocov end
 
 }
+
+renv_snapshot_reprex <- function(lockfile) {
+
+  fmt <- "<sup>Lockfile generated by renv %s.</sup>"
+  version <- sprintf(fmt, renv_package_version("renv"))
+
+  text <- c(
+    "<details style=\"margin-bottom: 10px;\">",
+    "<summary>Lockfile</summary>",
+    "```",
+    renv_lockfile_write(lockfile, file = NULL),
+    "```",
+    version,
+    "</details>"
+  )
+
+  output <- paste(text, collapse = "\n")
+  class(output) <- "knit_asis"
+  attr(output, "knit_cacheable") <- NA
+
+  output
+
+}
