@@ -1,7 +1,7 @@
 
-renv_tempfile <- function(pattern = "renv-",
-                          tmpdir = renv_tempdir(),
-                          fileext = "")
+renv_tempfile_path <- function(pattern = "renv-",
+                                 tmpdir = renv_tempdir_path(),
+                                 fileext = "")
 {
   path <- tempfile(pattern, tmpdir, fileext)
   norm <- renv_file_normalize(path, winslash = "/")
@@ -9,14 +9,14 @@ renv_tempfile <- function(pattern = "renv-",
   norm
 }
 
-renv_tempdir_impl <- function() {
+renv_tempdir_path_impl <- function() {
   dir <- Sys.getenv("RENV_TEMPDIR", unset = tempfile("renv-tempdir-"))
   dir.create(dir, recursive = TRUE, showWarnings = FALSE)
   Sys.chmod(dir, mode = "0700")
   dir
 }
 
-renv_tempdir <- function() {
-  renv_global("tempdir", renv_tempdir_impl())
+renv_tempdir_path <- function() {
+  renv_global("tempdir", renv_tempdir_path_impl())
 }
 
