@@ -91,32 +91,6 @@ test_that("we can successfully download files with different downloaders", {
 
 })
 
-# https://github.com/rstudio/renv/issues/390
-test_that("downloads still succeed even if HEAD request fails", {
-  skip_on_cran()
-
-  url <- "https://github.com/kevinushey/skeleton/releases/download/v1.0.1/skeleton_1.0.1.tar.gz"
-  destfile <- file.path(tempdir(), basename(url))
-  on.exit(unlink(destfile), add = TRUE)
-
-  # HEAD requests will fail on GitHub releases
-  expect_warning(
-    renv_download_headers(
-      url     = url,
-      type    = "github",
-      headers = list()
-    )
-  )
-
-  # but a plain old download should be fine
-  download(url, destfile)
-
-  # validate the md5sum
-  md5 <- tools::md5sum(destfile)
-  expect_equal(unname(md5), "9e978ca14adea985850f7913fc837166")
-
-})
-
 test_that("downloads work with file URIs", {
 
   renv_tests_scope()
@@ -131,7 +105,6 @@ test_that("downloads work with file URIs", {
 
 })
 
-
 test_that("downloads work with UNC paths on Windows", {
   skip_on_cran()
   skip_if_not(renv_platform_windows())
@@ -161,5 +134,12 @@ test_that("downloads work with UNC paths on Windows", {
 
 test_that("we can check that a URL is available", {
   skip_on_cran()
-  expect_true(renv_download_available("https://www.google.com"))
+
+  url <- "https://www.google.com"
+  expect_true(renv_download_available(url))
+
+  # also test the different methods
+  expect_true(renv_download_available_headers(url))
+  expect_true(renv_download_available_range(url))
+  expect_true(renv_download_available_fallback(url))
 })
