@@ -31,7 +31,7 @@ test_that("RENV_PATHS_PREFIX is respected", {
   libpath <- renv_paths_library()
   expect_true(grepl(os, libpath, fixed = TRUE))
 
-  prefix <- renv_prefix_platform()
+  prefix <- renv_platform_prefix()
   expect_true(startswith(prefix, os))
 
 })
@@ -41,3 +41,30 @@ test_that("RENV_PATHS_PREFIX is not normalized", {
   renv_paths_init()
   expect_identical(Sys.getenv("RENV_PATHS_PREFIX"), ".")
 })
+
+test_that("renv_path_normalize is correctly initialized", {
+
+  expect_identical(
+    renv_path_normalize,
+    if (renv_platform_windows())
+      renv_path_normalize_win32
+    else
+      renv_path_normalize_unix
+  )
+
+})
+
+test_that("UTF-8 paths can be normalized", {
+
+  skip_if(getRversion() < "4.0.0")
+
+  name <- enc2utf8("\u4f60\u597d")  # nihao
+  root <- normalizePath(tempdir(), winslash = "/", mustWork = TRUE)
+  path <- paste(root, name, sep = "/")
+  expect_true(file.create(path))
+
+  expected <- path
+  actual   <- renv_path_normalize(path)
+  expect_equal(expected, actual)
+
+})
