@@ -220,14 +220,22 @@ test_that("snapshot warns about unsatisfied dependencies", {
 
 test_that("snapshot records packages discovered in local sources", {
 
+  renv_scope_options(renv.tests.verbose = FALSE)
+
   renv_tests_scope("skeleton")
   renv_scope_envvars(RENV_PATHS_CACHE = tempfile())
 
   init(bare = TRUE)
 
   record <- list(Package = "skeleton", Version = "1.0.1", Source = "Local")
-  install(list(record))
+  records <- install(list(record))
 
+  # validate the record reported by install
+  skeleton <- records[["skeleton"]]
+  expect_equal(skeleton$Version, "1.0.1")
+  expect_equal(skeleton$Source, "Local")
+
+  # validate the record in the lockfile
   lockfile <- snapshot(lockfile = NULL)
   records <- renv_records(lockfile)
   skeleton <- records[["skeleton"]]
@@ -254,11 +262,22 @@ test_that("snapshot prefers RemoteType to biocViews", {
 })
 
 test_that("parse errors cause snapshot to abort", {
+
   renv_tests_scope()
+
+  # write invalid code to an R file
   writeLines("parse error", con = "parse-error.R")
-  init(bare = TRUE)
+
+  # init should succeed even with parse errors
+  local({
+    renv_scope_options(renv.tests.verbose = FALSE)
+    init(bare = TRUE)
+  })
+
+  # snapshots should fail when configured to do so
   renv_scope_options(renv.config.dependency.errors = "fatal")
   expect_error(snapshot())
+
 })
 
 test_that("records for packages available on other OSes are preserved", {
